@@ -112,7 +112,7 @@ __PACKAGE__->mk_inherited_merging_accessors(qw( tt_args config_callback ));
 *plugins           = \&plugin;
 *add_plugins       = \&add_plugin;
 
-our $VERSION = '0.04001';
+our $VERSION = '0.04002';
 $VERSION = eval $VERSION;
 
 Class::C3::initialize();
@@ -3169,7 +3169,7 @@ L<HTML::FormFu::Imager>
 
 L<Catalyst::Controller::HTML::FormFu>
 
-L<DBIx::Class::FormFu>
+L<HTML::FormFu::Model::DBIC>
 
 =head1 AUTHORS
 
