@@ -4,10 +4,10 @@ use strict;
 use base 'HTML::FormFu::Element::_Field';
 use Class::C3;
 
-use HTML::FormFu::Util qw/ xml_escape process_attrs /;
+use HTML::FormFu::Util qw( xml_escape process_attrs );
 
-__PACKAGE__->mk_accessors(qw/ field_type /);
-__PACKAGE__->mk_output_accessors(qw/ content /);
+__PACKAGE__->mk_item_accessors(qw( field_type ));
+__PACKAGE__->mk_output_accessors(qw( content ));
 
 sub new {
     my $self = shift->next::method(@_);
@@ -19,12 +19,13 @@ sub new {
 }
 
 sub render_data_non_recursive {
-    my $self = shift;
+    my ( $self, $args ) = @_;
 
     my $render = $self->next::method( {
             field_type => $self->field_type,
             content    => xml_escape( $self->content ),
-            @_ ? %{ $_[0] } : () } );
+            $args ? %$args : (),
+        } );
 
     return $render;
 }
@@ -61,7 +62,8 @@ sub _string_field {
 
     my $html .= sprintf qq{<button name="%s" type="%s"},
         $render->{nested_name},
-        $render->{field_type};
+        $render->{field_type},
+        ;
 
     if ( defined $render->{value} ) {
         $html .= sprintf qq{ value="%s"}, $render->{value};
@@ -69,7 +71,8 @@ sub _string_field {
 
     $html .= sprintf "%s>%s</button>",
         process_attrs( $render->{attributes} ),
-        ( defined $render->{content} ? $render->{content} : '' );
+        ( defined $render->{content} ? $render->{content} : '' ),
+        ;
 
     return $html;
 }
@@ -107,7 +110,7 @@ Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
