@@ -20,14 +20,14 @@ sub process {
         croak $@ if $@;
 
         push @errors, eval { $self->validate_values( $value, $params ) };
-        
+
         if ($@) {
             push @errors, $self->return_error($@);
         }
     }
     else {
         my $ok = eval { $self->validate_value( $value, $params ) };
-        
+
         if ( $@ or !$ok ) {
             push @errors, $self->return_error($@);
         }
@@ -43,7 +43,7 @@ sub validate_values {
 
     for my $value (@$values) {
         my $ok = eval { $self->validate_value( $value, $params ) };
-        
+
         if ( blessed $@ && $@->isa('HTML::FormFu::Exception::Validator') ) {
             push @errors, $@;
         }
@@ -85,6 +85,46 @@ HTML::FormFu::Validator - Validator Base Class
 
 =head1 CORE VALIDATORS
 
+=head1 BEST PRACTICES
+
+Try to avoid using callbacks if possible. Below is a more maintainable
+and reusable approach, which also keeps the code out of the controller.
+
+A normal application's directory would contain:
+
+    lib/HTML/FormFu/Constraint/MyApp/
+    lib/HTML/FormFu/Validator/MyApp/
+    lib/HTML/FormFu/Plugin/MyApp/
+    etc.
+
+Then, the form config file would just need:
+
+    validator: 'MyApp::SomeValidator'
+
+And the class would be something like this:
+
+    package HTML::FormFu::Validator::MyApp::SomeValidator;
+    use strict;
+    use warnings;
+    use base 'HTML::FormFu::Validator';
+
+    sub validate_value {
+        my ( $self, $value, $params ) = @_;
+
+        my $c = $self->form->stash->{context};
+
+        return 1 if $c->model('DBIC')->is_valid($value);
+
+        # assuming you want to return a custom error message
+        # which perhaps includes something retrieved from the model
+        # otherwise, just return 0
+        die HTML::FormFu::Exception::Validator->new({
+            message => 'custom error message',
+        });
+    }
+
+    1;
+
 =over
 
 =item L<HTML::FormFu::Validator::Callback>
